#
# spec file for package template-glib
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           template-glib
Version:        3.36.1
Release:        150600.1.2
Summary:        Library for generating text based on a template and user defined state
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://git.gnome.org/browse/template-glib/
Source0:        https://download.gnome.org/sources/template-glib/3.36/%{name}-%{version}.tar.xz

BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.51.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(vapigen)

%description
Template-GLib is a library for generating text based on a template and
user defined state. Template-GLib does not use a language runtime, so it is
safe to use from any GObject-Introspectable language.

%package -n     libtemplate_glib-1_0-0
Summary:        Library for generating text based on a template and user defined state
# Make the -lang package installable
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n libtemplate_glib-1_0-0
Template-GLib is a library for generating text based on a template and
user defined state. Template-GLib does not use a language runtime, so it is
safe to use from any GObject-Introspectable language.

%package -n     typelib-1_0-Template-1_0
Summary:        Introspection bindings for Template-GLib
Group:          System/Libraries

%description -n typelib-1_0-Template-1_0
Template-GLib is a library for generating text based on a template and
user defined state. Template-GLib does not use a language runtime, so it is
safe to use from any GObject-Introspectable language.

Template-GLib allows accessing properties on GObjects as well as call
simple methods via GObject-Introspection.

This package provides the introspection bindings.

%package        devel
Summary:        Development files for Template-GLib
Group:          Development/Languages/C and C++
Requires:       typelib-1_0-Template-1_0 = %{version}

%description    devel
Template-GLib is a library for generating text based on a template and
user defined state. Template-GLib does not use a language runtime, so it is
safe to use from any GObject-Introspectable language.

This package provides the development files.

%lang_package

%prep
%autosetup

%build
%meson \
	-Dtracing=false \
	-Dprofiling=false \
	-Dintrospection=enabled \
	-Dvapi=true \
	-Dgtk_doc=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%post -n libtemplate_glib-1_0-0 -p /sbin/ldconfig
%postun -n libtemplate_glib-1_0-0 -p /sbin/ldconfig

%files -n libtemplate_glib-1_0-0
%license COPYING
%{_libdir}/libtemplate_glib-1.0.so.0*

%files -n typelib-1_0-Template-1_0
%{_libdir}/girepository-1.0/Template-1.0.typelib

%files devel
%doc README.md
%doc %{_datadir}/gtk-doc/html/template-glib/
%dir %{_includedir}/template-glib-1.0
%{_includedir}/template-glib-1.0/*.h
%{_datadir}/gir-1.0/Template-1.0.gir
%{_libdir}/libtemplate_glib-1.0.so
%{_libdir}/pkgconfig/template-glib-1.0.pc
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/template-glib-1.0.deps
%{_datadir}/vala/vapi/template-glib-1.0.vapi

%files lang -f %{name}.lang

%changelog
* Mon Mar  6 2023 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + Fix leak of GObject Introspection interface info.
  + Document usage of package_subdir.
  + Updated translations.
* Sun Sep 18 2022 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + No changes since 3.35.0, stable bump only.
* Fri Aug 12 2022 dimstar@opensuse.org
- Update to version 3.35.0:
  + Build system improvements and test suites
  + Many fixes to TmplExpr lexing, parsing, and evaluation
  + A number of new AST nodes and symbo API
  + Various new builtin functions
  + Improved support for swallowing newlines from templates
- Adjust meson parameters according to upstream changes:
  + enable_tracing=false -> tracing=false
  + enable_profiling=false -> profiling=false
  + enable_g_doc=false -> gtk_doc=false
  + with_introspectin=true -> introspection=enabled
  + with_vapi=true -> vapi=true
* Sun Mar 20 2022 bjorn.lie@gmail.com
- Update to version 3.34.1:
  + Updated translations.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + No changes since 3.33.92.
* Fri Sep  6 2019 qkzhu@suse.com
- Update to version 3.33.92:
  + Updated meson build requirement.
  + Build fixes for macOS.
  + Translation updates.
* Wed Mar 13 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + Updated translations.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Improve cross-compilation support.
* Wed Sep 12 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Documentation fixes.
  + Check {{include}} for valid path.
  + Various G-I fixes.
* Wed Mar 14 2018 jengelh@inai.de
- Update descriptions.
* Wed Mar 14 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + No changes since 3.27.90.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb  5 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Allow iteration of string arrays (GStrv).
* Sat Nov 18 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + A number of imporovements to the template locator.
  + Support for more gobject introspection API calls.
  + You can know use typeof(expr) to get the GType of the result of
    the expression.
  + The token stream tries harder to supress newlines.
  + Require/version expression priority is now lower.
  + Some memory leaks were plugged.
  + Versioning of symbols is now down with export macros to be more
    portable for alternative platforms.
  + Now it is explicitly required a modern C standard.
  + Updated translations.
* Thu Oct  5 2017 dimstar@opensuse.org
- Update to version 3.26.1:
  + Enable C99 support specifically in meson.build.
  + Updated translations.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Don't store build dir in generated files to help with build
    reproducibility.
- Add gtk-doc BuildRequires, build documentation.
- Pass enable_tracing=false, enable_profiling=false,
  with_introspection=true, with_vapi=true and enable_gtk_doc=true
  to meson, ensure we build the features we want.
* Thu Sep  7 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Use LGPLv2.1+ consistently.
  + Fix unused variable in eval.
  + Check for version-script support by the linker.
  + Bump to more recent meson dependency.
  + Updated translations.
* Wed Aug 30 2017 dimstar@opensuse.org
- Provide template-glib by the shlib package: make the -lang
  package installable.
* Sun Jul 23 2017 zaitor@opensuse.org
- Initial packaging for openSUSE, version 3.25.3.
